/***************************************************************************
                          loadMD2.h  -  description
                             -------------------
    begin                : Die Jul 5 2005
    copyright            : (C) 2005 by Krippel Harald
    email                : harald@hte-develop.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef LOADMD2_H
#define LOADMD2_H

/**
  *@author Harald Krippel
  */

ssgEntity * LoadMD2( const char *filename, const ssgLoaderOptions* options);

#endif
